summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/petaltree2uml.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60 (patch)
treebabc4a761925023e16fa94633959f35d1c251887 /umbrello/umbrello/petaltree2uml.cpp
parent0813b39aed2cf4c84157a22c4c9594336d93d412 (diff)
downloadtdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.tar.gz
tdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/petaltree2uml.cpp')
-rw-r--r--umbrello/umbrello/petaltree2uml.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/umbrello/umbrello/petaltree2uml.cpp b/umbrello/umbrello/petaltree2uml.cpp
index 6bd4086f..8d56a3ec 100644
--- a/umbrello/umbrello/petaltree2uml.cpp
+++ b/umbrello/umbrello/petaltree2uml.cpp
@@ -129,12 +129,12 @@ public:
}
/**
* Insert the given UMLClassifierListItem at the tqparent Umbrello object.
* Abstract method to be implemented by inheriting classes.
* NB the tqparent Umbrello object is not included in the ClassifierListReader
* class - it must be added at inheriting classes.
*
* @param node The PetalNode which corresponds to the tqparent Umbrello object.
* @param o The UMLObject to insert.
*/
virtual void insertAtParent(const PetalNode *node, UMLObject *o) = 0;
@@ -249,7 +249,7 @@ public:
return new UMLAssociation(Uml::at_Generalization);
}
/**
* Override tqparent implementation: The secondary data is not for the
* UMLAssociation itself but for its role B object.
*/
void setTypeReferences(UMLObject *item,
@@ -282,7 +282,7 @@ public:
return new UMLAssociation(Uml::at_Realization);
}
/**
* Override tqparent implementation: The secondary data is not for the
* UMLAssociation itself but for its role B object.
*/
void setTypeReferences(UMLObject *item,
@@ -310,7 +310,7 @@ protected:
* @param node Pointer to the PetalNode which may contain a controlled unit
* @param name Name of the current node
* @param id TQUID of the current node
- * @param parentPkg Pointer to the current tqparent UMLPackage.
+ * @param parentPkg Pointer to the current parent UMLPackage.
* @return True if the node actually contained a controlled unit.
*/
bool handleControlledUnit(PetalNode *node, const TQString& name, Uml::IDType id, UMLPackage *parentPkg) {
@@ -455,9 +455,9 @@ bool umbrellify(PetalNode *node, UMLPackage *parentPkg = NULL) {
return true;
}
-Uml::ListView_Type folderType(UMLListViewItem *tqparent) {
+Uml::ListView_Type folderType(UMLListViewItem *parent) {
Uml::ListView_Type type = Uml::lvt_Unknown;
- switch (tqparent->getType()) {
+ switch (parent->getType()) {
case Uml::lvt_Logical_View:
case Uml::lvt_Logical_Folder:
type = Uml::lvt_Logical_Folder;
@@ -488,7 +488,7 @@ Uml::ListView_Type folderType(UMLListViewItem *tqparent) {
* Given a PetalNode for which the mapping to Umbrello is not yet
* implemented umbrellify() is a no-op but also returns true.
*/
-bool umbrellify(PetalNode *node, const TQString& modelsName, UMLListViewItem *tqparent) {
+bool umbrellify(PetalNode *node, const TQString& modelsName, UMLListViewItem *parent) {
if (node == NULL) {
kError() << "umbrellify(" << modelsName << "): node is NULL" << endl;
return false;
@@ -501,13 +501,13 @@ bool umbrellify(PetalNode *node, const TQString& modelsName, UMLListViewItem *tq
UMLListViewItem *item = NULL;
if (objType == "Class_Category") {
- Uml::ListView_Type lvType = folderType(tqparent);
- item = new UMLListViewItem( tqparent, name, lvType, id );
+ Uml::ListView_Type lvType = folderType(parent);
+ item = new UMLListViewItem( parent, name, lvType, id );
} else if (objType == "Class") {
TQString stereotype = clean(node->findAttribute("stereotype").string);
if (stereotype == "Actor") {
UMLActor *act = new UMLActor(name, id);
- item = new UMLListViewItem(tqparent, name, Uml::lvt_Actor, act);
+ item = new UMLListViewItem(parent, name, Uml::lvt_Actor, act);
obj = act;
} else {
kDebug() << "umbrellify(" << name << "): handling of Class stereotype "
@@ -515,16 +515,16 @@ bool umbrellify(PetalNode *node, const TQString& modelsName, UMLListViewItem *tq
}
} else if (objType == "UseCase") {
UMLUseCase *uc = new UMLUseCase(name, id);
- item = new UMLListViewItem(tqparent, name, Uml::lvt_UseCase, uc);
+ item = new UMLListViewItem(parent, name, Uml::lvt_UseCase, uc);
obj = uc;
} else if (objType == "SubSystem") {
UMLComponent *comp = new UMLComponent(name, id);
- item = new UMLListViewItem(tqparent, name, Uml::lvt_Component, comp);
+ item = new UMLListViewItem(parent, name, Uml::lvt_Component, comp);
obj = comp;
} else if (objType == "Processor" || objType == "Device") {
UMLNode *un = new UMLNode(name, id);
un->setStereotype(objType.lower());
- item = new UMLListViewItem(tqparent, name, Uml::lvt_Node, un);
+ item = new UMLListViewItem(parent, name, Uml::lvt_Node, un);
obj = un;
} else {
kDebug() << "umbrellify: object type " << objType
@@ -129,12 +129,12 @@ public:
}
/**
- * Insert the given UMLClassifierListItem at the tqparent Umbrello object.
+ * Insert the given UMLClassifierListItem at the parent Umbrello object.
* Abstract method to be implemented by inheriting classes.
@@ -129,12 +129,12 @@ public:
* Abstract method to be implemented by inheriting classes.
- * NB the tqparent Umbrello object is not included in the ClassifierListReader
+ * NB the parent Umbrello object is not included in the ClassifierListReader
* class - it must be added at inheriting classes.
*
@@ -129,12 +129,12 @@ public:
* class - it must be added at inheriting classes.
*
- * @param node The PetalNode which corresponds to the tqparent Umbrello object.
+ * @param node The PetalNode which corresponds to the parent Umbrello object.
* @param o The UMLObject to insert.
*/
@@ -249,7 +249,7 @@ public:
}
/**
- * Override tqparent implementation: The secondary data is not for the
+ * Override parent implementation: The secondary data is not for the
* UMLAssociation itself but for its role B object.
*/
@@ -282,7 +282,7 @@ public:
}
/**
- * Override tqparent implementation: The secondary data is not for the
+ * Override parent implementation: The secondary data is not for the
* UMLAssociation itself but for its role B object.
*/